@@ -133,7 +133,7 @@ class DB:
     lst = []
     for data in mycol.find():
       lst.append(data)
-    return dict(list[0])
+    return dict(lst)
 
   """
   Method to filter occurences in a collection in a database.
@@ -151,10 +151,10 @@ class DB:
     lst = []
     ID = 1 if ID == True else 0
     find = {"_id": ID}
-    #find.update(data)
-    for data in mycol.find({}, data).limit(limit):
+    find.update(data)
+    for data in mycol.find({}, find).limit(limit):
       lst.append(data)
-    return dict(list[0])
+    return dict(lst[0])
 
   """
   Method to find all query the occurences in a collection in a database.
@@ -175,7 +175,7 @@ class DB:
     data = mycol.find(query).limit(limit)
     for each in data:
       lst.append(each)
-    return dict(list[0])
+    return dict(lst[0])
 
   """
   Method to sort the collections in a database by a fieldname [field].
@@ -190,7 +190,7 @@ class DB:
     data = mycol.find().sort(field, asc).limit(limit)
     for each in data:
       lst.append(each)
-    return dict(list[0])
+    return dict(lst[0])
 
   """
   Method to delete one query from a collection in a database.
@@ -233,7 +233,7 @@ class DB:
     mycol.update_one(oldquery, newquery)
     for each in mycol.find():
       lst.append(each)
-    return dict(list[0])
+    return dict(lst[0])
 
   """
   Method to update many queries from a collection in a database (probably using regex or a modifier).
@@ -242,7 +242,7 @@ class DB:
   def updateMany(self, oldquery: dict, newquery: dict):
     mycol = DB.__createCol(self)
     lst = []
-    x = mycol.delete_many(oldquery, newquery)
+    x = mycol.update_many(oldquery, newquery)
     return f"{x.modified_count} documents modified"
 
   """
